Learn R Programming

tidysmd (version 0.2.0)

tidysmd-package: tidysmd: Tidy Standardized Mean Differences

Description

Tidy standardized mean differences ('SMDs'). 'tidysmd' uses the 'smd' package to calculate standardized mean differences for variables in a data frame, returning the results in a tidy format.

Arguments

Author

Maintainer: Malcolm Barrett malcolmbarrett@gmail.com (ORCID)

See Also