tidysmd-package: tidysmd: Tidy Standardized Mean Differences
Description
Tidy standardized mean differences ('SMDs'). 'tidysmd' uses the 'smd' package to calculate standardized mean differences for variables in a data frame, returning the results in a tidy format.